@@ -9,8 +9,10 @@ use Try::Tiny;
 use Data::Dumper;
 use Sys::Hostname;
 use Plack::Util;
+use Class::Inspector;
+use Scalar::Util qw(blessed);
 
-our $VERSION = '1.03_2';
+our $VERSION = '1.04_01';
 
 # Basic attributes
 attr -host => hostname;
@@ -65,8 +67,12 @@ sub new_anon {
     my $class = shift;
 
     # make sure we don't eval something dodgy
-    die "invalid class $class"
-        unless !ref $class && $class->isa(__PACKAGE__);
+    die "invalid class for new_anon"
+        if ref $class                         # not a string
+        || !$class                            # not an empty string, undef or 0
+        || !Class::Inspector->loaded($class)  # not a loaded class
+        || !$class->isa(__PACKAGE__)          # not a correct class
+    ;
 
     my $anon_class = "Kelp::Anonymous::$class" . ++$last_anon;
     my $err = do {
@@ -255,13 +261,25 @@ sub psgi {
         $self->finalize;
     }
     catch {
-        my $message = $self->long_error ? longmess($_) : $_;
+        my $exception = $_;
+        my $res = $self->res;
 
-        # Log error
-        $self->logger( 'critical', $message ) if $self->can('logger');
+        if (blessed $exception && $exception->isa('Kelp::Exception')) {
+            # No logging here, since it is a message for the user with a code
+            # rather than a real exceptional case
+            # (Nothing really broke, user code invoked this)
 
-        # Render 500
-        $self->res->render_500($_);
+            $res->render_exception($exception);
+        }
+        else {
+            my $message = $self->long_error ? longmess($exception) : $exception;
+
+            # Log error
+            $self->logger( 'critical', $message ) if $self->can('logger');
+
+            # Render 500
+            $res->render_500($_);
+        }
         $self->finalize;
     };
 }
@@ -276,7 +294,13 @@ sub finalize {
 #----------------------------------------------------------------
 # Request and Response shortcuts
 #----------------------------------------------------------------
-sub param { shift->req->param(@_) }
+sub param {
+    my $self = shift;
+    unshift @_, $self->req;
+
+    # goto will allow carp show the correct caller
+    goto $_[0]->can('param');
+}
 
 sub session { shift->req->session(@_) }
 
@@ -574,7 +598,8 @@ A shortcut to C<$self-E<gt>req-E<gt>param>:
         }
     }
 
-See L<Kelp::Request> for more information and examples.
+This function can be tricky to use because of context sensivity. See
+L<Kelp::Request/param> for more information and examples.
 
 =head2 session
 
