@@ -1,8 +1,11 @@
 package Kelp::Module::Config;
+
 use Kelp::Base 'Kelp::Module';
 use Carp;
 use Try::Tiny;
 use Test::Deep;
+use Path::Tiny;
+
 
 # Extension to look for
 attr ext => 'pl';
@@ -90,14 +93,15 @@ sub load {
     my ( $self, $filename ) = @_;
 
     # Open and read file
-    open( my $in, "<:encoding(UTF-8)", $filename )
-      or do {
+    my $text;
+    try {
+        $text = path($filename)->slurp_utf8;
+    };
+
+    if (!defined $text) {
         warn "Can not read config file " . $filename;
         return {};
-      };
-
-    my $text = do { local $/ = undef; <$in> };
-    close($in);
+    }
 
     my ( $hash, $error );
     {
@@ -336,8 +340,6 @@ C<+> in front of the name will add the elements to the array:
         '+middleware' => ['Baz']    # Add 'Baz' in development
     }
 
-=cut
-
 =item
 
 C<-> in front of the name will remove the elements from the array:
@@ -352,8 +354,6 @@ C<-> in front of the name will remove the elements from the array:
         '-modules' => [qw/Logger/]  # Remove the Logger modules in test mode
     }
 
-=cut
-
 =item
 
 No sigil will cause the array to be completely replaced:
@@ -368,8 +368,6 @@ No sigil will cause the array to be completely replaced:
         middleware => []    # No middleware in CLI
     }
 
-=cut
-
 =back
 
 Note that the merge sigils only apply to arrays. All other types will keep the
